@@ -1,8 +1,9 @@
-import os
 import json
+from pathlib import Path
 from itertools import chain
 from types import MethodType
 
+from django.conf import settings
 from django.contrib import admin, messages
 from django.contrib.contenttypes.forms import BaseGenericInlineFormSet
 from django.contrib.contenttypes.models import ContentType
@@ -62,7 +63,7 @@ class SortableAdminBase:
     @property
     def media(self):
         css = {'all': ['adminsortable2/css/sortable.css']}
-        js = ['adminsortable2/js/adminsortable2.min.js']
+        js = ['adminsortable2/js/adminsortable2{}.js'.format('' if settings.DEBUG else '.min')]
         return super().media + widgets.Media(css=css, js=js)
 
     def get_formset_kwargs(self, request, obj, inline, prefix):
@@ -95,9 +96,9 @@ class SortableAdminMixin(SortableAdminBase):
         opts = self.model._meta
         app_label = opts.app_label
         return [
-            os.path.join('adminsortable2', app_label, opts.model_name, 'change_list.html'),
-            os.path.join('adminsortable2', app_label, 'change_list.html'),
-            'adminsortable2/change_list.html'
+            Path('adminsortable2') / Path(app_label) / Path(opts.model_name) / Path('change_list.html'),
+            Path('adminsortable2') / Path(app_label) / Path('change_list.html'),
+            Path('adminsortable2/change_list.html'),
         ]
 
     def __init__(self, model, admin_site):
@@ -403,6 +404,7 @@ class SortableAdminMixin(SortableAdminBase):
     def changelist_view(self, request, extra_context=None):
         extra_context = extra_context or {}
         extra_context['sortable_update_url'] = self.get_update_url(request)
+        extra_context['base_change_list_template'] = super().change_list_template or 'admin/change_list.html'
         return super().changelist_view(request, extra_context)
 
     def get_update_url(self, request):
@@ -429,10 +431,13 @@ class CustomInlineFormSetMixin:
         self.default_order_direction = default_order_direction
         self.default_order_field = default_order_field
         if default_order_field:
-            if default_order_field not in self.form.base_fields:
-                self.form.base_fields[default_order_field] = self.model._meta.get_field(default_order_field).formfield()
+            if default_order_field in self.form.base_fields:
+                order_field = self.form.base_fields[default_order_field]
+            else:
+                order_field = self.model._meta.get_field(default_order_field).formfield()
+                self.form.base_fields[default_order_field] = order_field
+                self.form.declared_fields[default_order_field] = order_field
 
-            order_field = self.form.base_fields[default_order_field]
             order_field.is_hidden = True
             order_field.required = False
             order_field.widget = widgets.HiddenInput(attrs={'class': '_reorder_'})
@@ -478,13 +483,20 @@ class SortableInlineAdminMixin:
     formset = CustomInlineFormSet
 
     def __init__(self, parent_model, admin_site):
-        assert isinstance(admin_site._registry[parent_model], SortableAdminBase), \
-            "{} must inherit from SortableAdminBase since {} inherits from SortableInlineAdminMixin.".format(
-                admin_site._registry[parent_model], self.__class__.__name__
-            )
+        if parent_model in admin_site._registry:
+            assert isinstance(admin_site._registry[parent_model], SortableAdminBase), \
+                "{} must inherit from SortableAdminBase since {} inherits from SortableInlineAdminMixin.".format(
+                    admin_site._registry[parent_model], self.__class__.__name__
+                )
         self.default_order_direction, self.default_order_field = _get_default_ordering(self.model, self)
         super().__init__(parent_model, admin_site)
 
+    def get_fields(self, *args, **kwargs):
+        fields = super().get_fields(*args, **kwargs)
+        if self.default_order_field not in fields:
+            fields.append(self.default_order_field)
+        return fields
+
 
 class CustomGenericInlineFormSet(CustomInlineFormSetMixin, BaseGenericInlineFormSet):
     def get_max_order(self):
